==> libreoffice_3.5.7.orig.tar.xz: libreoffice-3.5.7/odk/examples/DevelopersGuide/Components/Thumbs/org/openoffice/comp/test/Thumbs.java <==
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  the BSD license.
 *
 *  Copyright 2000, 2010 Oracle and/or its affiliates.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. Neither the name of Sun Microsystems, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 *  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 *  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 *  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *************************************************************************/
package org.openoffice.comp.test;

import com.sun.star.uno.UnoRuntime;


/**
 * Test class for testing the ImageShrink service skeleton.
 * Note: the image shrink functionality is not implemented
 */
public class Thumbs {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        try {
            // get the remote office component context
            com.sun.star.uno.XComponentContext xRemoteContext =
                com.sun.star.comp.helper.Bootstrap.bootstrap();

            System.out.println("Connected to a running office ...");

            // use the generated default create method to instantiate a
            // new ImageShrink object
            org.openoffice.test.XImageShrinkFilter xImageShrinkFilter =
                org.openoffice.test.ImageShrink.create(xRemoteContext);

            System.out.println("ImageShrink component succesfully instantiated");

            java.io.File f = new java.io.File(".");
            System.out.println("set SourceDrectory ...");
            xImageShrinkFilter.setSourceDirectory(f.getCanonicalPath());

            System.out.println("source Directory = "
                               + xImageShrinkFilter.getSourceDirectory());
        }
        catch (java.lang.Exception e){
            System.err.println("Error: " + e);
            e.printStackTrace();
        }
        finally {
            System.exit(0);
        }
    }
}

==> libreoffice-5.2.4.2.tar.xz: libreoffice-5.2.4.2/odk/examples/DevelopersGuide/Components/Thumbs/org/openoffice/comp/test/Thumbs.java <==
/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  the BSD license.
 *
 *  Copyright 2000, 2010 Oracle and/or its affiliates.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  3. Neither the name of Sun Microsystems, Inc. nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 *  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 *  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 *  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *************************************************************************/
package org.openoffice.comp.test;


/**
 * Test class for testing the ImageShrink service skeleton.
 * Note: the image shrink functionality is not implemented
 */
public class Thumbs {

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        try {
            // get the remote office component context
            com.sun.star.uno.XComponentContext xRemoteContext =
                com.sun.star.comp.helper.Bootstrap.bootstrap();

            System.out.println("Connected to a running office ...");

            // use the generated default create method to instantiate a
            // new ImageShrink object
            org.openoffice.test.XImageShrinkFilter xImageShrinkFilter =
                org.openoffice.test.ImageShrink.create(xRemoteContext);

            System.out.println("ImageShrink component successfully instantiated");

            java.io.File f = new java.io.File(".");
            System.out.println("set SourceDrectory ...");
            xImageShrinkFilter.setSourceDirectory(f.getCanonicalPath());

            System.out.println("source Directory = "
                               + xImageShrinkFilter.getSourceDirectory());
        }
        catch (java.lang.Exception e){
            System.err.println("Error: " + e);
            e.printStackTrace();
        }
        finally {
            System.exit(0);
        }
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
